@@ -46,7 +46,7 @@ class CSSStyleSheetImpl;
 class HTMLBaseElementImpl : public HTMLElementImpl
 {
 public:
-    HTMLBaseElementImpl(DocumentPtr *doc);
+    HTMLBaseElementImpl(DocumentImpl *doc);
     ~HTMLBaseElementImpl();
 
     DOMString href() const { return m_href; }
@@ -71,7 +71,7 @@ protected:
 class HTMLLinkElementImpl : public khtml::CachedObjectClient, public HTMLElementImpl
 {
 public:
-    HTMLLinkElementImpl(DocumentPtr *doc);
+    HTMLLinkElementImpl(DocumentImpl *doc);
     ~HTMLLinkElementImpl();
 
     virtual Id id() const;
@@ -121,7 +121,7 @@ protected:
 class HTMLMetaElementImpl : public HTMLElementImpl
 {
 public:
-    HTMLMetaElementImpl(DocumentPtr *doc);
+    HTMLMetaElementImpl(DocumentImpl *doc);
 
     ~HTMLMetaElementImpl();
 
@@ -141,7 +141,7 @@ protected:
 class HTMLScriptElementImpl : public HTMLElementImpl, public khtml::CachedObjectClient
 {
 public:
-    HTMLScriptElementImpl(DocumentPtr *doc);
+    HTMLScriptElementImpl(DocumentImpl *doc);
     ~HTMLScriptElementImpl();
     
     virtual void insertedIntoDocument();
@@ -163,7 +163,7 @@ private:
 class HTMLStyleElementImpl : public HTMLElementImpl
 {
 public:
-    HTMLStyleElementImpl(DocumentPtr *doc);
+    HTMLStyleElementImpl(DocumentImpl *doc);
     ~HTMLStyleElementImpl();
 
     virtual Id id() const;
@@ -191,7 +191,7 @@ protected:
 class HTMLTitleElementImpl : public HTMLElementImpl
 {
 public:
-    HTMLTitleElementImpl(DocumentPtr *doc);
+    HTMLTitleElementImpl(DocumentImpl *doc);
 
     ~HTMLTitleElementImpl();
 
