@@ -55,16 +55,16 @@ using namespace khtml;
 
 // -------------------------------------------------------------------------
 
-HTMLAppletElementImpl::HTMLAppletElementImpl(DocumentPtr *doc)
-  : HTMLElementImpl(doc)
+HTMLAppletElementImpl::HTMLAppletElementImpl(DocumentImpl *doc)
+: HTMLElementImpl(doc)
+, m_allParamsAvailable(false)
 {
-    appletInstance = 0;
-    m_allParamsAvailable = false;
 }
 
 HTMLAppletElementImpl::~HTMLAppletElementImpl()
 {
-    delete appletInstance;
+    // m_appletInstance should have been cleaned up in detach().
+    assert(!m_appletInstance);
 }
 
 NodeImpl::Id HTMLAppletElementImpl::id() const
@@ -196,8 +196,8 @@ KJS::Bindings::Instance *HTMLAppletElementImpl::getAppletInstance() const
     if (!part || !part->javaEnabled())
         return 0;
 
-    if (appletInstance)
-        return appletInstance;
+    if (m_appletInstance)
+        return m_appletInstance.get();
     
     RenderApplet *r = static_cast<RenderApplet*>(m_render);
     if (r) {
@@ -206,10 +206,10 @@ KJS::Bindings::Instance *HTMLAppletElementImpl::getAppletInstance() const
             // Call into the part (and over the bridge) to pull the Bindings::Instance
             // from the guts of the plugin.
             void *_view = r->widget()->getView();
-            appletInstance = KWQ(part)->getAppletInstanceForView((NSView *)_view);
+            m_appletInstance = KWQ(part)->getAppletInstanceForView((NSView *)_view);
         }
     }
-    return appletInstance;
+    return m_appletInstance.get();
 }
 
 void HTMLAppletElementImpl::closeRenderer()
@@ -222,6 +222,13 @@ void HTMLAppletElementImpl::closeRenderer()
     HTMLElementImpl::closeRenderer();
 }
 
+void HTMLAppletElementImpl::detach()
+{
+    m_appletInstance = 0;
+
+    HTMLElementImpl::detach();
+}
+
 bool HTMLAppletElementImpl::allParamsAvailable()
 {
     return m_allParamsAvailable;
@@ -230,12 +237,22 @@ bool HTMLAppletElementImpl::allParamsAvailable()
 
 // -------------------------------------------------------------------------
 
-HTMLEmbedElementImpl::HTMLEmbedElementImpl(DocumentPtr *doc)
-    : HTMLElementImpl(doc), embedInstance(0)
-{}
+HTMLEmbedElementImpl::HTMLEmbedElementImpl(DocumentImpl *doc)
+: HTMLElementImpl(doc)
+{
+}
 
 HTMLEmbedElementImpl::~HTMLEmbedElementImpl()
 {
+    // m_embedInstance should have been cleaned up in detach().
+    assert(!m_embedInstance);
+}
+
+void HTMLEmbedElementImpl::detach()
+{
+    m_embedInstance = 0;
+
+    HTMLElementImpl::detach();
 }
 
 NodeImpl::Id HTMLEmbedElementImpl::id() const
@@ -250,8 +267,8 @@ KJS::Bindings::Instance *HTMLEmbedElementImpl::getEmbedInstance() const
     if (!part)
         return 0;
 
-    if (embedInstance)
-        return embedInstance;
+    if (m_embedInstance)
+        return m_embedInstance.get();
     
     RenderPartObject *r = static_cast<RenderPartObject*>(m_render);
     if (r) {
@@ -259,13 +276,13 @@ KJS::Bindings::Instance *HTMLEmbedElementImpl::getEmbedInstance() const
             // Call into the part (and over the bridge) to pull the Bindings::Instance
             // from the guts of the Java VM.
             void *_view = r->widget()->getView();
-            embedInstance = KWQ(part)->getEmbedInstanceForView((NSView *)_view);
+            m_embedInstance = KWQ(part)->getEmbedInstanceForView((NSView *)_view);
             // Applet may specified with <embed> tag.
-            if (!embedInstance)
-                embedInstance = KWQ(part)->getAppletInstanceForView((NSView *)_view);
+            if (!m_embedInstance)
+                m_embedInstance = KWQ(part)->getAppletInstanceForView((NSView *)_view);
         }
     }
-    return embedInstance;
+    return m_embedInstance.get();
 }
 #endif
 
@@ -380,12 +397,9 @@ bool HTMLEmbedElementImpl::isURLAttribute(AttributeImpl *attr) const
 
 // -------------------------------------------------------------------------
 
-HTMLObjectElementImpl::HTMLObjectElementImpl(DocumentPtr *doc) 
-#if APPLE_CHANGES
-: HTMLElementImpl(doc), m_imageLoader(0), objectInstance(0)
-#else
-: HTMLElementImpl(doc), m_imageLoader(0)
-#endif
+HTMLObjectElementImpl::HTMLObjectElementImpl(DocumentImpl *doc) 
+: HTMLElementImpl(doc)
+, m_imageLoader(0)
 {
     needWidgetUpdate = false;
     m_useFallbackContent = false;
@@ -394,6 +408,9 @@ HTMLObjectElementImpl::HTMLObjectElementImpl(DocumentPtr *doc)
 
 HTMLObjectElementImpl::~HTMLObjectElementImpl()
 {
+    // m_objectInstance should have been cleaned up in detach().
+    assert(!m_objectInstance);
+    
     delete m_imageLoader;
 }
 
@@ -409,8 +426,8 @@ KJS::Bindings::Instance *HTMLObjectElementImpl::getObjectInstance() const
     if (!part)
         return 0;
 
-    if (objectInstance)
-        return objectInstance;
+    if (m_objectInstance)
+        return m_objectInstance.get();
 
     if (RenderObject *r = m_render) {
         if (r->isWidget()) {
@@ -418,16 +435,16 @@ KJS::Bindings::Instance *HTMLObjectElementImpl::getObjectInstance() const
                 if (NSView *view = widget->getView())  {
                     // Call into the part (and over the bridge) to pull the Bindings::Instance
                     // from the guts of the plugin.
-                    objectInstance = KWQ(part)->getObjectInstanceForView(view);
+                    m_objectInstance = KWQ(part)->getObjectInstanceForView(view);
                     // Applet may specified with <object> tag.
-                    if (!objectInstance)
-                        objectInstance = KWQ(part)->getAppletInstanceForView(view);
+                    if (!m_objectInstance)
+                        m_objectInstance = KWQ(part)->getAppletInstanceForView(view);
                 }
             }
         }
     }
 
-    return objectInstance;
+    return m_objectInstance.get();
 }
 #endif
 
@@ -592,6 +609,8 @@ void HTMLObjectElementImpl::detach()
         needWidgetUpdate = true;
     }
 
+    m_objectInstance = 0;
+
     HTMLElementImpl::detach();
 }
 
@@ -655,7 +674,7 @@ void HTMLObjectElementImpl::renderFallbackContent()
 
 // -------------------------------------------------------------------------
 
-HTMLParamElementImpl::HTMLParamElementImpl(DocumentPtr *doc)
+HTMLParamElementImpl::HTMLParamElementImpl(DocumentImpl *doc)
     : HTMLElementImpl(doc)
 {
 }
