@@ -184,12 +184,27 @@ public:
     DocumentImpl(DOMImplementationImpl *_implementation, KHTMLView *v);
     ~DocumentImpl();
 
+    virtual void removedLastRef();
+
+    // Nodes belonging to this document hold "self-only" references -
+    // these are enough to keep the document from being destroyed, but
+    // not enough to keep it from removing its children. This allows a
+    // node that outlives its document to still have a valid document
+    // pointer without introducing reference cycles
+
+    void selfOnlyRef() { ++m_selfOnlyRefCount; }
+    void selfOnlyDeref() {
+        --m_selfOnlyRefCount;
+        if (!m_selfOnlyRefCount && !refCount())
+            delete this;
+    }
+
     // DOM methods & attributes for Document
 
     DocumentTypeImpl *doctype() const;
 
     DOMImplementationImpl *implementation() const;
-    virtual ElementImpl *documentElement() const;
+    ElementImpl *documentElement();
     virtual ElementImpl *createElement ( const DOMString &tagName, int &exceptioncode );
     DocumentFragmentImpl *createDocumentFragment ();
     TextImpl *createTextNode ( const DOMString &data );
@@ -203,6 +218,8 @@ public:
     ElementImpl *getElementById ( const DOMString &elementId ) const;
     ElementImpl *elementFromPoint ( const int _x, const int _y ) const;
 
+    virtual void childrenChanged();
+
     // Actually part of HTMLDocument, but used for giving XML documents a window title as well
     DOMString title() const { return m_title; }
     void setTitle(DOMString, NodeImpl *titleElement = 0);
@@ -309,6 +326,7 @@ public:
     
     void open();
     void implicitOpen();
+    void cancelParsing();
     void close();
     void implicitClose();
     void write ( const DOMString &text );
@@ -424,14 +442,14 @@ public:
 
     QStringList availableStyleSheets() const;
 
-    NodeImpl *focusNode() const { return m_focusNode; }
+    NodeImpl *focusNode() const { return m_focusNode.get(); }
     bool setFocusNode(NodeImpl *newFocusNode);
     void clearSelectionIfNeeded(NodeImpl *newFocusNode);
 
-    NodeImpl *hoverNode() const { return m_hoverNode; }
+    NodeImpl *hoverNode() const { return m_hoverNode.get(); }
     void setHoverNode(NodeImpl *newHoverNode);
     
-    NodeImpl *activeNode() const { return m_activeNode; }
+    NodeImpl *activeNode() const { return m_activeNode.get(); }
     void setActiveNode(NodeImpl *newActiveNode);
 
     // Updates for :target (CSS3 selector).
@@ -466,6 +484,7 @@ public:
     typedef QMap<QString, ProcessingInstructionImpl*> LocalStyleRefs;
     LocalStyleRefs* localStyleRefs() { return &m_localStyleRefs; }
 
+    void handleWindowEvent(EventImpl *evt, bool useCapture);
     virtual void defaultEventHandler(EventImpl *evt);
     void setHTMLWindowEventListener(int id, EventListener *listener);
     EventListener *getHTMLWindowEventListener(int id);
@@ -639,9 +658,10 @@ protected:
 
     QColor m_textColor;
 
-    NodeImpl *m_focusNode;
-    NodeImpl *m_hoverNode;
-    NodeImpl *m_activeNode;
+    khtml::SharedPtr<NodeImpl> m_focusNode;
+    khtml::SharedPtr<NodeImpl> m_hoverNode;
+    khtml::SharedPtr<NodeImpl> m_activeNode;
+    khtml::SharedPtr<ElementImpl> m_documentElement;
 
     unsigned int m_domtree_version;
     
@@ -687,7 +707,7 @@ protected:
     
     DOMString m_title;
     bool m_titleSetExplicitly;
-    NodeImpl *m_titleElement;
+    khtml::SharedPtr<NodeImpl> m_titleElement;
     
     RenderArena* m_renderArena;
 
@@ -732,7 +752,6 @@ public:
 
     bool inPageCache();
     void setInPageCache(bool flag);
-    void restoreRenderer(khtml::RenderObject* render);
 
     void passwordFieldAdded();
     void passwordFieldRemoved();
@@ -794,6 +813,7 @@ private:
     QValueList<khtml::DashboardRegionValue> m_dashboardRegions;
     bool m_hasDashboardRegions;
     bool m_dashboardRegionsDirty;
+    int m_selfOnlyRefCount;
     
     QPtrDict< QDict<HTMLInputElementImpl> > *m_selectedRadioButtons;
 
@@ -803,7 +823,7 @@ private:
 class DocumentFragmentImpl : public NodeBaseImpl
 {
 public:
-    DocumentFragmentImpl(DocumentPtr *doc);
+    DocumentFragmentImpl(DocumentImpl *doc);
 
     // DOM methods overridden from  parent classes
     virtual DOMString nodeName() const;
@@ -820,7 +840,7 @@ public:
 class DocumentTypeImpl : public NodeImpl
 {
 public:
-    DocumentTypeImpl(DOMImplementationImpl *_implementation, DocumentPtr *doc,
+    DocumentTypeImpl(DOMImplementationImpl *_implementation, DocumentImpl *doc,
                      const DOMString &qualifiedName, const DOMString &publicId,
                      const DOMString &systemId);
     ~DocumentTypeImpl();
