@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003 Apple Computer, Inc.  All rights reserved.
+ * Copyright (C) 2004 Apple Computer, Inc.  All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -55,6 +55,7 @@ public:
 	KeyRelease,
         Paint,
         Resize,
+        Wheel,
 	KParts
     };
 
@@ -73,6 +74,7 @@ class QMouseEvent : public QEvent {
 public:
     QMouseEvent(Type, const QPoint &pos, int button, int state);
     QMouseEvent(Type, NSEvent *);
+    explicit QMouseEvent(Type); // uses AppKit's current event
 
     const QPoint &pos() const { return _position; }
     int x() const { return _position.x(); }
@@ -83,9 +85,12 @@ public:
     ButtonState state() const { return static_cast<ButtonState>(_state); }
     ButtonState stateAfter() const { return static_cast<ButtonState>(_stateAfter); }
 
-    int clickCount() { return _clickCount; }
+    int clickCount() const { return _clickCount; }
+    bool isDoubleClick() const { return _clickCount > 0 && _clickCount % 2 == 0; }
 
 private:
+    void fixState();
+
     QPoint _position;
     int _button;
     int _state;
@@ -137,9 +142,40 @@ public:
     static Reason reason() { return Other; }
 };
 
+class QWheelEvent : public QEvent {
+public:
+    QWheelEvent(const QPoint &position, const QPoint &globalPosition, int delta, int state, Orientation orientation)
+        : QEvent(Wheel), _position(position), _globalPosition(globalPosition), _delta(delta), _state(state)
+        , _orientation(orientation), _isAccepted(false)
+        { }
+    QWheelEvent(NSEvent *);
+
+    const QPoint &pos() const { return _position; }
+    const QPoint &globalPos() const { return _globalPosition; }
+    int delta() const { return _delta; }
+    int state() const { return _state; }
+    Orientation orientation() const { return _orientation; }
+    bool isAccepted() const { return _isAccepted; }
+
+    int x() const { return _position.x(); }
+    int y() const { return _position.y(); }
+    int globalX() const { return _globalPosition.x(); }
+    int globalY() const { return _globalPosition.y(); }
+
+    void accept() { _isAccepted = true; }
+    void ignore() { _isAccepted = false; }
+
+private:
+    QPoint _position;
+    QPoint _globalPosition;
+    int _delta;
+    int _state;
+    Orientation _orientation;
+    bool _isAccepted;
+};
+
 class QHideEvent;
 class QShowEvent;
-class QWheelEvent;
 class QContextMenuEvent;
 
 class QResizeEvent : public QEvent {
