@@ -30,5 +30,10 @@
 + (WebCoreGraphicsBridge *)sharedBridge;
 - (void)setFocusRingStyle:(NSFocusRingPlacement)placement radius:(int)radius color:(NSColor *)color;
 - (void)setDraggingImage:(NSImage *)dragImage at:(NSPoint)dragLoc;
+- (void)setAdditionalPatternPhase:(NSPoint)phase;
+
+- (CGColorSpaceRef)createRGBColorSpace;
+- (CGColorSpaceRef)createGrayColorSpace;
+- (CGColorSpaceRef)createCMYKColorSpace;
 
 @end
